<?php
/*
Plugin Name: Maika Gallery
Plugin URI:  http://plugins.roninwp.com/maika
Description: Advanced gallery plugin for show portfolio, gallery and more your work
Version:     1.21
Author:      20script
Author URI:  https://www.20script.ir
Domain Path: /languages
Text Domain: fat-maika
*/

if (!defined('ABSPATH')) die('-1');
defined('FAT_MAIKA_GALLERY_POST_TYPE') or define('FAT_MAIKA_GALLERY_POST_TYPE', 'fat-maika');
defined('FAT_MAIKA_DIR_PATH') or define('FAT_MAIKA_DIR_PATH', plugin_dir_path(__FILE__));
defined('FAT_MAIKA_PLUGIN_URL') or define('FAT_MAIKA_PLUGIN_URL', plugins_url('',__FILE__));

if (!class_exists('FAT_Maika')) {
    class FAT_Maika
    {
        function __construct()
        {
            add_action('init', array($this, 'register_post_types'), 5);
            add_action('init', array($this, 'register_page_builder_shortcode'), 7);
            add_action('init', array($this, 'maika_load_textdomain'));

            add_action('admin_enqueue_scripts', array($this, 'enqueue_script'), 0);
            add_filter('fat_cmb_register_metabox', array($this, 'register_meta_boxes'));
            add_shortcode('fat_maika', array($this, 'register_shortcode'));
            if (is_admin()) {
                add_action('admin_enqueue_scripts', array($this, 'enqueue_script'), 0);
                $this->includes_meta();
                $this->includes();

                add_filter('manage_edit-' . FAT_MAIKA_GALLERY_POST_TYPE . '_columns', array($this, 'add_admin_listing_shortcode_columns'));
                add_action('manage_' . FAT_MAIKA_GALLERY_POST_TYPE . '_posts_custom_column', array($this, 'set_admin_listing_shortcode_columns_value'), 10, 2);
            }else{
                $this->includes();
                //add_action('wp_enqueue_scripts',array($this,'frontend_enqueue_ajax'));
            }
        }

        function maika_load_textdomain()
        {
            $domain = dirname(plugin_basename(__FILE__));
            $locale = apply_filters('plugin_locale', get_locale(), $domain);
            load_textdomain('maika', trailingslashit(WP_LANG_DIR) . 'plugins' . '/' . $domain . '-' . $locale . '.mo');
            load_plugin_textdomain('maika', false, basename(dirname(__FILE__)) . '/languages/');
        }

        function register_post_types()
        {
            $post_type = $slug = FAT_MAIKA_GALLERY_POST_TYPE;
            $name = $singular_name = 'Maika Gallery';

            if (post_type_exists($post_type)) {
                return;
            }

            register_post_type($post_type,
                array(
                    'label' => $name,
                    'description' => esc_html__('Maika Gallery Description', 'fat-maika'),
                    'labels' => array(
                        'name' => $name,
                        'singular_name' => $singular_name,
                        'menu_name' => ucfirst($name),
                        'parent_item_colon' => esc_html__('Parent Item:', 'fat-maika'),
                        'all_items' => esc_html__('All Gallery', 'fat-maika'),
                        'view_item' => esc_html__('View Item', 'fat-maika'),
                        'add_new_item' => sprintf(esc_html__('Add New  %s', 'fat-maika'), $name),
                        'add_new' => esc_html__('Add New Gallery', 'fat-maika'),
                        'edit_item' => esc_html__('Edit Gallery', 'fat-maika'),
                        'update_item' => esc_html__('Update Gallery', 'fat-maika'),
                        'search_items' => esc_html__('Search Item', 'fat-maika'),
                        'not_found' => esc_html__('Not found', 'fat-maika'),
                        'not_found_in_trash' => esc_html__('Not found in Trash', 'fat-maika'),
                    ),
                    'supports' => array('title'),
                    'public' => false,
                    'show_ui' => true,
                    '_builtin' => false,
                    'has_archive' => true,
                    'exclude_from_search' => true,
                    'menu_icon' => 'dashicons-images-alt2',
                    'rewrite' => array('slug' => $slug, 'with_front' => true),
                )
            );
        }

        function register_meta_boxes($meta_boxes)
        {
            $gallery_shortcode = $desc = '';
            if (isset($_GET['post'])) {
                $gallery_shortcode = '[fat_maika id="' . $_GET['post'] . '"]';
                $desc = esc_html__('To use shortcode, please select and copy this shortcode and paste to page, post or anywhere','maika');
            }
            $meta_boxes[] = array(
                'title' => esc_html__('Gallery Shortcode', 'maika'),
                'id' => 'fat-mb-gallery-shortcode',
                'priority' => 'high',
                'pages' => array(FAT_MAIKA_GALLERY_POST_TYPE),
                'fields' => array(
                    array(
                        'label' => esc_html__('Gallery Shortcode', 'maika'),
                        'id' => 'gallery_shortcode',
                        'type' => 'heading',
                        'std' =>  $gallery_shortcode,
                        'description' => $desc,
                    ),
                )
            );

            $meta_boxes[] = array(
                'title' => esc_html__('Gallery Config', 'maika'),
                'id' => 'fat-mb-gallery-config',
                'priority' => 'high',
                'tabs' => array(
                    array(
                        'id' => 'tab-layout',
                        'icon' => '',
                        'title' => esc_html__('Layout', 'fat-maika')
                    ),
                    array(
                        'id' => 'tab-gallery',
                        'icon' => '',
                        'title' => esc_html__('Gallery', 'fat-maika')
                    ),
                    array(
                        'id' => 'tab-filter',
                        'icon' => '',
                        'title' => esc_html__('Filter & Sort', 'fat-maika')
                    ),
                    array(
                        'id' => 'tab-pagination',
                        'icon' => '',
                        'title' => esc_html__('Pagination', 'fat-maika')
                    ),
                    array(
                        'id' => 'tab-skin',
                        'icon' => '',
                        'title' => esc_html__('Skin & Animation', 'fat-maika')
                    ),
                    array(
                        'id' => 'tab-font',
                        'icon' => '',
                        'title' => esc_html__('Font & Color', 'fat-maika')
                    ),
                    array(
                        'id' => 'tab-css',
                        'icon' => '',
                        'title' => esc_html__('Custom CSS', 'fat-maika')
                    ),
                ),
                'pages' => array(FAT_MAIKA_GALLERY_POST_TYPE),
                'fields' => array(
                    /** Tab layout */
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Choose Layout:', 'maika'),
                        'id' => 'layout_type',
                        'type' => 'image_select',
                        'options' => array(
                            array(
                                'title' => "Grid layout",
                                'image' => plugins_url('assets/images/layouts/grid.jpg', __FILE__),
                                'value' => 'grid'
                            ),
                            array(
                                'title' => "Masonry layout",
                                'image' => plugins_url('assets/images/layouts/masonry.jpg', __FILE__),
                                'value' => 'masonry'
                            ),
                            array(
                                'title' => "Before After",
                                'image' => plugins_url('assets/images/layouts/before-after.jpg', __FILE__),
                                'value' => 'before-after'
                            ),
                            array(
                                'title' => "Album Preview",
                                'image' => plugins_url('assets/images/layouts/album-preview.jpg', __FILE__),
                                'value' => 'album-preview'
                            ),
                            array(
                                'title' => "Carousel Slide",
                                'image' => plugins_url('assets/images/layouts/carousel-slider.jpg', __FILE__),
                                'value' => 'carousel-slide'
                            ),
                            array(
                                'title' => "Horizontal Slide",
                                'image' => plugins_url('assets/images/layouts/horizonal-slide.jpg', __FILE__),
                                'value' => 'horizontal-slide'
                            ),
                            array(
                                'title' => "Photo Pile",
                                'image' => plugins_url('assets/images/layouts/photopile.jpg', __FILE__),
                                'value' => 'photopile'
                            ),
                            array(
                                'title' => "Justified",
                                'image' => plugins_url('assets/images/layouts/justified.jpg', __FILE__),
                                'value' => 'justified'
                            ),
                            array(
                                'title' => "Time line",
                                'image' => plugins_url('assets/images/layouts/timeline.jpg', __FILE__),
                                'value' => 'timeline'
                            ),
                        ),
                        'slide' => true,
                        'column' => 4,
                        'std' => 'grid',
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Navigation', 'maika'),
                        'id' => 'carousel_nav',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'dot' => esc_html__('Dot navigation', 'maika'),
                            'nav' => esc_html__('Arrow navigation', 'maika'),
                        ),
                        'std' => 'dot',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'carousel-slide',
                            'compare' => '='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Auto play', 'maika'),
                        'id' => 'carousel_autoplay',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            '1' => esc_html__('Yes', 'maika'),
                            '0' => esc_html__('No', 'maika'),
                        ),
                        'std' => '1',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'carousel-slide',
                            'compare' => '='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Play timeout', 'maika'),
                        'id' => 'carousel_timeout',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 10000,
                        'step' => 100,
                        'std' => '4000',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'carousel-slide',
                            'compare' => '='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Loop', 'maika'),
                        'id' => 'carousel_loop',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            '0' => esc_html__('No', 'maika'),
                            '1' => esc_html__('Yes', 'maika'),
                        ),
                        'std' => '1',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'carousel-slide',
                            'compare' => '='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Right to left (RTL)', 'maika'),
                        'id' => 'carousel_rtl',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            '0' => esc_html__('No', 'maika'),
                            '1' => esc_html__('Yes', 'maika'),
                        ),
                        'std' => '0',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'carousel-slide',
                            'compare' => '='
                        ),
                    ),

                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Popup gallery', 'maika'),
                        'id' => 'popup_gallery',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'fat-lightbox-gallery' => esc_html__('Light box popup gallery', 'maika'),
                            'fat-magnific-gallery' => esc_html__('Magnific popup gallery', 'maika'),
                        ),
                        'std' => 'fat-lightbox-gallery',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'grid,masonry,horizontal-slide,carousel-slide',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Popup Image size', 'maika'),
                        'id' => 'popup_image_size',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'full' => esc_html__('Full size', 'maika'),
                            'medium' => esc_html__('Medium size', 'maika'),
                            'large' => esc_html__('Large size', 'maika'),
                        ),
                        'std' => 'full',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'before-after',
                            'compare' => '!='
                        ),
                        'description' => esc_html__('Option to change image size in popup gallery','maika')
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Image height', 'maika'),
                        'id' => 'photopile_image_height',
                        'type' => 'number',
                        'min' => 100,
                        'max' => 450,
                        'step' => 10,
                        'std' => '100',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'photopile',
                            'compare' => '='
                        ),
                        'description' => esc_html__('Height of image in photopile layout. The width of image will be auto crop base on height value','maika')
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Album preview aimation', 'maika'),
                        'id' => 'album_animation',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'no-animation' => esc_html__('None', 'maika'),
                            'random' => esc_html__('Random', 'maika'),
                            'fat-album-anim-1' => esc_html__('Animation 01', 'maika'),
                            'fat-album-anim-2' => esc_html__('Animation 02', 'maika'),
                            'fat-album-anim-3' => esc_html__('Animation 03', 'maika'),
                            'fat-album-anim-4' => esc_html__('Animation 04', 'maika'),
                            'fat-album-anim-5' => esc_html__('Animation 05', 'maika'),
                            'fat-album-anim-6' => esc_html__('Animation 06', 'maika'),
                            'fat-album-anim-7' => esc_html__('Animation 07', 'maika'),
                            'fat-album-anim-8' => esc_html__('Animation 08', 'maika'),
                            'fat-album-anim-9' => esc_html__('Animation 09', 'maika'),
                        ),
                        'std' => 'random',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'album-preview',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Column', 'maika'),
                        'id' => 'column',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            '1' => esc_html__('1 column', 'maika'),
                            '2' => esc_html__('2 columns', 'maika'),
                            '3' => esc_html__('3 columns', 'maika'),
                            '4' => esc_html__('4 columns', 'maika'),
                            '6' => esc_html__('6 columns', 'maika')
                        ),
                        'std' => '3',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'grid,masonry,flip,album-preview,horizontal-slide,carousel-slide',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Gutter', 'maika'),
                        'id' => 'gutter',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'fat-padding-0' => esc_html__('None', 'maika'),
                            'fat-padding-5' => esc_html__('5 pixel', 'maika'),
                            'fat-padding-10' => esc_html__('10 pixel', 'maika'),
                            'fat-padding-15' => esc_html__('15 pixel', 'maika'),
                            'fat-padding-20' => esc_html__('20 pixel', 'maika')
                        ),
                        'std' => 'fat-padding-10',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'grid,masonry,flip,album-preview',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Image width', 'maika'),
                        'id' => 'image_width',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 5000,
                        'step' => 1,
                        'std' => '375',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'grid,album-preview,horizontal-slide,before-after,carousel-slide',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Image height', 'maika'),
                        'id' => 'image_height',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 5000,
                        'step' => 1,
                        'std' => '275',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'grid,album-preview,horizontal-slide,before-after,carousel-slide',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Comparison', 'maika'),
                        'id' => 'comparison',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'horizontal' => esc_html__('Horizontal', 'maika'),
                            'vertical' => esc_html__('Vertical', 'maika'),
                        ),
                        'std' => 'horizontal',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'before-after',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Image before', 'maika'),
                        'id' => 'image_before',
                        'type' => 'single_image',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'before-after',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Caption before', 'maika'),
                        'id' => 'caption_before',
                        'type' => 'text',
                        'description' => esc_html__('Set empty to hide caption','maika'),
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'before-after',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Image after', 'maika'),
                        'id' => 'image_after',
                        'type' => 'single_image',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'before-after',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Caption after', 'maika'),
                        'id' => 'caption_after',
                        'type' => 'text',
                        'description' => esc_html__('Set empty to hide caption','maika'),
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'before-after',
                            'compare' => 'in'
                        ),
                    ),

                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Row height', 'maika'),
                        'id' => 'row_height',
                        'type' => 'number',
                        'min' => 50,
                        'max' => 900,
                        'std' => 100,
                        'step' => 1,
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'justified',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Margin', 'maika'),
                        'id' => 'margin',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 30,
                        'step' => 1,
                        'std' => 1,
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'justified,,carousel-slide',
                            'compare' => 'in'
                        ),
                        'description' => esc_html__('Margin between items (pixel)','fat-event')
                    ),

                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Iterm per page', 'maika'),
                        'id' => 'justified_item_per_page',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 30,
                        'step' => 1,
                        'std' => '',
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'justified',
                            'compare' => 'in'
                        ),
                        'description' => esc_html__('Set item per page when use infinite scroll. Set 0 or empty to ignore infinite scroll','maika')
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Justify last row', 'maika'),
                        'id' => 'justify_last_row',
                        'type' => 'check',
                        'options' => array(
                          '1' => esc_html__('Yes','maika')
                        ),
                        'std' => 0,
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'justified',
                            'compare' => 'in'
                        ),
                        'description' => esc_html__('Decide to justify the last row. If choose this, the last row will be fit width of content ','maika')
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Display random image', 'maika'),
                        'id' => 'justify_random',
                        'type' => 'check',
                        'options' => array(
                            '1' => esc_html__('Yes','maika')
                        ),
                        'std' => 0,
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'justified',
                            'compare' => 'in'
                        ),
                        'description' => esc_html__('Decide to order random when show up image ','maika')
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Unload Modernizr', 'maika'),
                        'id' => 'unload_modernizr',
                        'type' => 'check',
                        'options' => array(
                            '1' => esc_html__('Yes', 'maika'),
                        ),
                        'std' => '',
                        'description' => esc_html__('Unload modernizr to fix conflict masonry, timeline, horizontal-slide  layout with theme (ex: AVADA)','maika'),
                        'depend_field' => array(
                            'field' => 'layout_type',
                            'value' => 'grid,timeline,masonry,horizontal-slide,carousel-slide',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Disable download button', 'maika'),
                        'id' => 'disable_download',
                        'type' => 'check',
                        'options' => array(
                            'on' => esc_html__('Yes','maika'),
                        ),
                        'std' => '',
                        'depend_field' => array(
                            'field' => 'popup_gallery',
                            'value' => 'fat-lightbox-gallery,lightbox-gallery',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Disable share in popup gallery', 'maika'),
                        'id' => 'disable_share',
                        'type' => 'check',
                        'options' => array(
                            'on' => esc_html__('Yes','maika'),
                        ),
                        'std' => 'on',
                        'depend_field' => array(
                            'field' => 'popup_gallery',
                            'value' => 'fat-lightbox-gallery,lightbox-gallery',
                            'compare' => 'in'
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-layout',
                        'label' => esc_html__('Show thumbnail at default in popup gallery', 'maika'),
                        'id' => 'show_thumbnail',
                        'type' => 'check',
                        'options' => array(
                            'on' => esc_html__('Yes','maika'),
                        ),
                        'std' => '',
                        'depend_field' => array(
                            'field' => 'popup_gallery',
                            'value' => 'fat-lightbox-gallery,lightbox-gallery',
                            'compare' => 'in'
                        ),
                    ),

                    /** tab gallery */
                    array(
                        'tab_id' => 'tab-gallery',
                        'label' => esc_html__('Create Category and choose image for gallery', 'maika'),
                        'id' => 'gallery_images',
                        'type' => 'category_images',
                        'std' => '',
                    ),

                    /** Tab filter */
                    array(
                        'tab_id' => 'tab-filter',
                        'label' => esc_html__('Enable/Disable filter', 'maika'),
                        'id' => 'enable_filter',
                        'type' => 'radio',
                        'options' => array(
                            'on' => esc_html__('Turn on', 'maika'),
                            'off' => esc_html__('Turn off', 'maika'),
                        ),
                        'std' => 'on'
                    ),
                    array(
                        'tab_id' => 'tab-filter',
                        'label' => esc_html__('Disable "ALL" category filter', 'maika'),
                        'id' => 'disable_all_filter',
                        'type' => 'radio',
                        'options' => array(
                            'on' => esc_html__('Yes', 'maika'),
                            'off' => esc_html__('No', 'maika'),
                        ),
                        'std' => 'off',
                        'depend_field' => array(
                            'field' => 'enable_filter',
                            'value' => 'on',
                            'compare' => '='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-filter',
                        'label' => esc_html__('Show filter as dropdown on mobile', 'maika'),
                        'id' => 'filter_dropdown_mobile',
                        'type' => 'radio',
                        'options' => array(
                            'on' => esc_html__('Yes', 'maika'),
                            'off' => esc_html__('No', 'maika'),
                        ),
                        'std' => 'off',
                        'depend_field' => array(
                            'field' => 'enable_filter',
                            'value' => 'on',
                            'compare' => '='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-filter',
                        'label' => esc_html__('Filter layout:', 'maika'),
                        'id' => 'filter_layout',
                        'type' => 'image_select',
                        'column' => 2,
                        'item-height' => 'auto',
                        'item-width' => '100%',
                        'options' => array(
                            array(
                                'title' => "Skin 01",
                                'image' => plugins_url('assets/images/filter/skin-1.png', __FILE__),
                                'value' => 'cat-skin-01'
                            ),
                            array(
                                'title' => "Skin 02",
                                'image' => plugins_url('assets/images/filter/skin-2.png', __FILE__),
                                'value' => 'cat-skin-02'
                            ),
                            array(
                                'title' => "Skin 03",
                                'image' => plugins_url('assets/images/filter/skin-3.png', __FILE__),
                                'value' => 'cat-skin-03'
                            ),
                            array(
                                'title' => "Skin 04",
                                'image' => plugins_url('assets/images/filter/skin-4.png', __FILE__),
                                'value' => 'cat-skin-04'
                            ),
                        ),
                        'slide' => false,
                        'std' => 'cat-skin-01',
                        'depend_field' => array(
                            'field' => 'enable_filter',
                            'value' => 'on',
                            'compare' => '='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-filter',
                        'label' => esc_html__('Filter align', 'maika'),
                        'id' => 'filter_align',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'text-left' => esc_html__('At left', 'maika'),
                            'text-center' => esc_html__('At center', 'maika'),
                            'text-right' => esc_html__('At right', 'maika'),
                        ),
                        'std' => 'text-center',
                        'depend_field' => array(
                            'field' => 'enable_filter',
                            'value' => 'on',
                            'compare' => '='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-filter',
                        'label' => esc_html__('Order', 'maika'),
                        'id' => 'order',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'NONE' => esc_html__('None', 'maika'),
                            'DATE' => esc_html__('Date (Ascending)', 'maika'),
                            'DATE_DESC' => esc_html__('Date (Descending)', 'maika'),
                            'RANDOM' => esc_html__('Random', 'maika'),
                        ),
                        'std' => 'RANDOM'
                    ),

                    /** Tab pagination */
                    array(
                        'tab_id' => 'tab-pagination',
                        'label' => esc_html__('Paging type', 'maika'),
                        'id' => 'paging_type',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'load-more' => esc_html__('Load more button', 'maika'),
                            'infinite' => esc_html__('Infinite (auto load more when scroll bottom', 'maika'),
                            'show-all' => esc_html__('Show all item, not use paging', 'maika'),
                        ),
                        'std' => 'show-all'
                    ),
                    array(
                        'tab_id' => 'tab-pagination',
                        'label' => esc_html__('Item per page', 'maika'),
                        'id' => 'item_per_page',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                        'depend_field' => array(
                            'field' => 'paging_type',
                            'value' => 'show-all',
                            'compare' => '!='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-pagination',
                        'label' => esc_html__('Total item', 'maika'),
                        'id' => 'total_item',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                        'description' => 'Set empty to get all item'
                    ),
                    array(
                        'tab_id' => 'tab-pagination',
                        'label' => esc_html__('Background paging color', 'maika'),
                        'id' => 'bg_paging_color',
                        'type' => 'color',
                        'std' => '#343434',
                        'depend_field' => array(
                            'field' => 'paging_type',
                            'value' => 'show-all',
                            'compare' => '!='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-pagination',
                        'label' => esc_html__('Background paging hover/active color', 'maika'),
                        'id' => 'bg_paging_active_color',
                        'type' => 'color',
                        'std' => '#fff',
                        'depend_field' => array(
                            'field' => 'paging_type',
                            'value' => 'show-all',
                            'compare' => '!='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-pagination',
                        'label' => esc_html__('Paging text color', 'maika'),
                        'id' => 'paging_text_color',
                        'type' => 'color',
                        'std' => '#fff',
                        'depend_field' => array(
                            'field' => 'paging_type',
                            'value' => 'show-all',
                            'compare' => '!='
                        ),
                    ),
                    array(
                        'tab_id' => 'tab-pagination',
                        'label' => esc_html__('Paging text hover/active color', 'maika'),
                        'id' => 'paging_text_active_color',
                        'type' => 'color',
                        'std' => '#343434',
                        'depend_field' => array(
                            'field' => 'paging_type',
                            'value' => 'show-all',
                            'compare' => '!='
                        ),
                    ),

                    /** Tab skin */
                    array(
                        'tab_id' => 'tab-skin',
                        'label' => esc_html__('Item skin:', 'maika'),
                        'id' => 'skin',
                        'type' => 'image_select',
                        'column' => 4,
                        'item-height' => 'auto',
                        'item-width' => '100%',
                        'options' => array(
                            array(
                                'title' => "Skin 01",
                                'image' => plugins_url('assets/images/skins/item-skin-1.jpg', __FILE__),
                                'value' => 'item-skin-01'
                            ),
                            array(
                                'title' => "Skin 02",
                                'image' => plugins_url('assets/images/skins/item-skin-2.jpg', __FILE__),
                                'value' => 'item-skin-02'
                            ),
                            array(
                                'title' => "Skin 03",
                                'image' => plugins_url('assets/images/skins/item-skin-3.jpg', __FILE__),
                                'value' => 'item-skin-03'
                            ),
                            array(
                                'title' => "Skin 04",
                                'image' => plugins_url('assets/images/skins/item-skin-4.jpg', __FILE__),
                                'value' => 'item-skin-04'
                            ),
                            array(
                                'title' => "Skin 05",
                                'image' => plugins_url('assets/images/skins/item-skin-5.jpg', __FILE__),
                                'value' => 'item-skin-05'
                            ),
                            array(
                                'title' => "Skin 06",
                                'image' => plugins_url('assets/images/skins/item-skin-6.jpg', __FILE__),
                                'value' => 'item-skin-06'
                            ),
                            array(
                                'title' => "Skin 07 (Image click to detail)",
                                'image' => plugins_url('assets/images/skins/item-skin-7.jpg', __FILE__),
                                'value' => 'item-skin-07'
                            ),
                            array(
                                'title' => "Skin 08 (Image click to gallery)",
                                'image' => plugins_url('assets/images/skins/item-skin-7.jpg', __FILE__),
                                'value' => 'item-skin-08'
                            ),
                            array(
                                'title' => "Skin 09",
                                'image' => plugins_url('assets/images/skins/item-skin-9.jpg', __FILE__),
                                'value' => 'item-skin-09'
                            ),
                            array(
                                'title' => "Skin 10 (Image & Title click to detail)",
                                'image' => plugins_url('assets/images/skins/item-skin-7.jpg', __FILE__),
                                'value' => 'item-skin-10'
                            ),
                        ),
                        'slide' => true,
                        'std' => 'item-skin-01',
                        /*  'depend_field' => array(
                              'field'   => 'enable_filter',
                              'value'   => 'on',
                              'compare' => '='
                          ),*/
                    ),
                    array(
                        'tab_id' => 'tab-skin',
                        'label' => esc_html__('Image scale and blur when hover', 'maika'),
                        'id' => 'image_scale_when_hover',
                        'type' => 'check',
                        'options' => array(
                          'on' => esc_html__('Yes','maika'),
                        ),
                        'std' => 'on'
                    ),
                    array(
                        'tab_id' => 'tab-skin',
                        'label' => esc_html__('Animation', 'maika'),
                        'id' => 'animation',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'none' => esc_html__('None', 'maika'),
                            'bounceInDown' => 'bounceInDown',
                            'bounceInLeft' => 'bounceInLeft',
                            'bounceInRight' => 'bounceInRight',
                            'bounceInUp' => 'bounceInUp',
                            'fadeInUp' => 'fadeInUp',
                            'fadeInDown' => 'fadeInDown',
                            'fadeInLeft' => 'fadeInLeft',
                            'fadeInRight' => 'fadeInRight',
                            'flipInX' => 'flipInX',
                            'slideInUp' => 'slideInUp',
                            'zoomIn' => 'zoomIn'
                        ),
                        'std' => 'none'
                    ),
                    array(
                        'tab_id' => 'tab-skin',
                        'label' => esc_html__('Animation duration (milisecond)', 'maika'),
                        'id' => 'animation_duration',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 2000,
                        'step' => 50,
                        'std' => 200
                    ),

                    /** Tab font & color */
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Filter font size', 'maika'),
                        'id' => 'filter_font_size',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 2000,
                        'step' => 1,
                        'std' => 14
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Filter style', 'maika'),
                        'id' => 'filter_style',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'none' => esc_html__('None', 'maika'),
                            'uppercase' => esc_html__('Uppercase', 'maika'),
                            'lowercase' => esc_html__('Lowercase', 'maika')
                        ),
                        'std' => 'none'
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Filter background color', 'maika'),
                        'id' => 'filter_bg_color',
                        'type' => 'color',
                        'std' => '#f1f1f1',
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Filter background hover/active color', 'maika'),
                        'id' => 'filter_bg_active_color',
                        'type' => 'color',
                        'std' => '#faa71a',
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Filter text color', 'maika'),
                        'id' => 'filter_text_color',
                        'type' => 'color',
                        'std' => '#343434',
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Filter text hover/active color', 'maika'),
                        'id' => 'filter_text_active_color',
                        'type' => 'color',
                        'std' => '#343434',
                    ),

                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Title font size', 'maika'),
                        'id' => 'title_font_size',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 2000,
                        'step' => 1,
                        'std' => 16
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Title style', 'maika'),
                        'id' => 'title_style',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'none' => esc_html__('None', 'maika'),
                            'uppercase' => esc_html__('Uppercase', 'maika'),
                            'lowercase' => esc_html__('Lowercase', 'maika')
                        ),
                        'std' => 'none'
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Title text color', 'maika'),
                        'id' => 'title_color',
                        'type' => 'color',
                        'std' => '#343434',
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Title hover/active color', 'maika'),
                        'id' => 'title_active_color',
                        'type' => 'color',
                        'std' => '#343434',
                    ),

                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Category font size', 'maika'),
                        'id' => 'category_font_size',
                        'type' => 'number',
                        'min' => 0,
                        'max' => 2000,
                        'step' => 1,
                        'std' => 16
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Category style', 'maika'),
                        'id' => 'category_style',
                        'type' => 'select',
                        'multiple' => false,
                        'options' => array(
                            'none' => esc_html__('None', 'maika'),
                            'uppercase' => esc_html__('Uppercase', 'maika'),
                            'lowercase' => esc_html__('Lowercase', 'maika')
                        ),
                        'std' => 'none'
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Category color', 'maika'),
                        'id' => 'category_color',
                        'type' => 'color',
                        'std' => '#343434',
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Category hover/active color', 'maika'),
                        'id' => 'category_active_color',
                        'type' => 'color',
                        'std' => '#343434',
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Icon color', 'maika'),
                        'id' => 'icon_color',
                        'type' => 'color',
                        'std' => '#343434',
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Icon background color', 'maika'),
                        'id' => 'icon_bg_color',
                        'type' => 'color',
                        'std' => 'rgba(0,0,0,0.7)',
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Background overlay hover color', 'maika'),
                        'id' => 'bg_hover_color',
                        'type' => 'color',
                        'std' => 'rgba(0,0,0,0.7)',
                        'description' => esc_html__('Background overlay on image when hover', 'maika')
                    ),

                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Navigation color', 'maika'),
                        'id' => 'nav_color',
                        'type' => 'color',
                        'std' => '#ddd',
                        'description' => esc_html__('Navigation color for carousel slide layout', 'maika')
                    ),
                    array(
                        'tab_id' => 'tab-font',
                        'label' => esc_html__('Navigation hover color', 'maika'),
                        'id' => 'nav_hover_color',
                        'type' => 'color',
                        'std' => '#faa71a',
                        'description' => esc_html__('Navigation hover color for carousel slide layout', 'maika')
                    ),
                    /** Tab custom css */
                    array(
                        'tab_id' => 'tab-css',
                        'label' => esc_html__('Custom Css', 'maika'),
                        'id' => 'custom_css',
                        'type' => 'ace',
                        'mode' => 'css',
                        'std' => '',
                    ),
                )

            );
            return $meta_boxes;

        }

        function register_shortcode($atts){
            if(!isset($atts['id']) || $atts['id']==''){
                return;
            }
            $gallery_id = $atts['id'];
            $gallery_config = get_post_meta($gallery_id,'fat-mb-gallery-config',true);
            $disable_download = isset($gallery_config['disable_download'][0]) && $gallery_config['disable_download'][0]=='on'? 'on' : 'off';
            $disable_share = isset($gallery_config['disable_share'][0]) && $gallery_config['disable_share'][0]=='on'? 'on' : 'off';
            $show_thumbnail = isset($gallery_config['show_thumbnail'][0]) && $gallery_config['show_thumbnail'][0]=='on'? 'on' : 'off';
            $layout_type = isset($gallery_config['layout_type']) ? $gallery_config['layout_type'] : 'grid';
            $layout_path = plugin_dir_path(__FILE__) . 'templates/layouts/'.$layout_type.'.php';

            $image_width = isset($gallery_config['image_width']) ? $gallery_config['image_width'] : 375;
            $image_height = isset($gallery_config['image_height']) ? $gallery_config['image_height'] : 275;
            $popup_image_size = isset($gallery_config['popup_image_size']) && $gallery_config['popup_image_size'] ? $gallery_config['popup_image_size'] : 'full';
            $custom_css = isset($gallery_config['custom_css']) ? $gallery_config['custom_css'] : '';
            $unload_modernizr = isset($gallery_config['unload_modernizr'][0]) ? $gallery_config['unload_modernizr'][0] : '0';

            if($layout_type!='before-after'){
                $gallery_images = isset($gallery_config['gallery_images']) ? $gallery_config['gallery_images'] : array();
                $popup_gallery = isset($gallery_config['popup_gallery']) ? $gallery_config['popup_gallery'] : 'fat-lightbox-gallery';

                $column = isset($gallery_config['column']) ? $gallery_config['column'] : 3;
                $gutter = isset($gallery_config['gutter']) ? $gallery_config['gutter'] : 'fat-padding-0';
                $enable_filter = isset($gallery_config['enable_filter']) && $gallery_config['enable_filter']=='on';
                $disable_all_filter = isset($gallery_config['disable_all_filter']) ?  $gallery_config['disable_all_filter'] : '';
                $filter_dropdown_mobile = isset($gallery_config['filter_dropdown_mobile']) ?  $gallery_config['filter_dropdown_mobile'] : '';
                $filter_layout = isset($gallery_config['filter_layout']) ? $gallery_config['filter_layout'] : 'skin-01';
                $filter_align = isset($gallery_config['filter_align']) ? $gallery_config['filter_align'] : 'text-center';
                $order = isset($gallery_config['order']) ? $gallery_config['order'] : 'NONE';
                $paging_type = isset($gallery_config['paging_type']) ? $gallery_config['paging_type'] : 'show-all';
                $item_per_page = isset($gallery_config['item_per_page']) ? $gallery_config['item_per_page'] : '';
                $total_item = isset($gallery_config['total_item']) ? $gallery_config['total_item'] : '';
                $prev_text = isset($gallery_config['prev_text']) ? $gallery_config['prev_text'] : '';
                $next_text = isset($gallery_config['next_text']) ? $gallery_config['next_text'] : '';
                $skin = isset($gallery_config['skin']) ? $gallery_config['skin'] : 'skin-01';
                $image_scale_when_hover = isset($gallery_config['image_scale_when_hover'][0]) && $gallery_config['image_scale_when_hover'][0]=='on'? 'has-image-scale-hover' : '';
                $animation = isset($gallery_config['animation']) ? $gallery_config['animation'] : 'none';
                $has_animation = $animation !=='none' ? ' has-animation' : '';
                $animation_duration = isset($gallery_config['animation_duration']) ? $gallery_config['animation_duration'] : '0';

                $bg_paging_color = isset($gallery_config['bg_paging_color']) ? $gallery_config['bg_paging_color'] : '#343434';
                $bg_paging_active_color = isset($gallery_config['bg_paging_active_color']) ? $gallery_config['bg_paging_active_color'] : '#343434';
                $paging_text_color = isset($gallery_config['paging_text_color']) ? $gallery_config['paging_text_color'] : '#fff';
                $paging_text_active_color = isset($gallery_config['paging_text_active_color']) ? $gallery_config['paging_text_active_color'] : '#fff';

                $filter_font_size = isset($gallery_config['filter_font_size']) ? $gallery_config['filter_font_size'] : '14';
                $filter_style = isset($gallery_config['filter_style']) ? $gallery_config['filter_style'] : 'none';
                $filter_bg_color = isset($gallery_config['filter_bg_color']) ? $gallery_config['filter_bg_color'] : '#f1f1f1';
                $filter_bg_active_color = isset($gallery_config['filter_bg_color']) ? $gallery_config['filter_bg_color'] : '#faa71a';
                $filter_text_color = isset($gallery_config['filter_text_color']) ? $gallery_config['filter_text_color'] : '#343434';
                $filter_text_active_color = isset($gallery_config['filter_text_active_color']) ? $gallery_config['filter_text_active_color'] : '#343434';

                $title_font_size = isset($gallery_config['title_font_size']) ? $gallery_config['title_font_size'] : '16';
                $title_style = isset($gallery_config['title_style']) ? $gallery_config['title_style'] : 'none';
                $title_color = isset($gallery_config['title_color']) ? $gallery_config['title_color'] : '#343434';
                $title_active_color = isset($gallery_config['title_active_color']) ? $gallery_config['title_active_color'] : '#343434';

                $category_font_size = isset($gallery_config['category_font_size']) ? $gallery_config['category_font_size'] : '16';
                $category_style = isset($gallery_config['category_style']) ? $gallery_config['category_style'] : 'none';
                $category_color = isset($gallery_config['category_color']) ? $gallery_config['category_color'] : '#343434';
                $category_active_color = isset($gallery_config['category_active_color']) ? $gallery_config['category_active_color'] : '#343434';

                $icon_color = isset($gallery_config['icon_color']) ? $gallery_config['icon_color'] : '#343434';
                $icon_bg_color = isset($gallery_config['icon_bg_color']) ? $gallery_config['icon_bg_color'] : 'rgba(0,0,0,0.7)';
                $bg_hover_color = isset($gallery_config['bg_hover_color']) ? $gallery_config['bg_hover_color'] : 'rgba(255,255,255,0.7)';
            }else{
                $image_before = isset($gallery_config['image_before']) ? $gallery_config['image_before'] : '';
                $image_after = isset($gallery_config['image_after']) ? $gallery_config['image_after'] : '';
                $comparison = isset($gallery_config['comparison']) ? $gallery_config['comparison'] : 'horizontal';
                $caption_before = isset($gallery_config['caption_before']) ? $gallery_config['caption_before'] : '';
                $caption_after = isset($gallery_config['caption_after']) ? $gallery_config['caption_after'] : '';
                if($image_before!='' && $image_after!=''){
                    if($gallery_config['image_width']!='' && $gallery_config['image_height']!=''){
                        $resize = fat_maika_matthewruddy_image_resize_id($image_before, $image_width, $image_height);

                        if ($resize != null && is_array($resize)){
                            $image_before = $resize['url'];
                        }
                        $resize = fat_maika_matthewruddy_image_resize_id($image_after, $image_width, $image_height);
                        if ($resize != null && is_array($resize)){
                            $image_after = $resize['url'];
                        }
                    }else{
                        $image_before = wp_get_attachment_image_url($image_before,'full');
                        $image_after = wp_get_attachment_image_url($image_after,'full');
                    }
                }
            }

            if(file_exists($layout_path)){
                $this->frontend_enqueue($layout_type, $unload_modernizr);
                ob_start();
                include($layout_path);
                $ret = ob_get_contents();
                $ret .= FAT_Maika_Utils::enqueue_custom_css($gallery_id, $gallery_config);
                ob_end_clean();
                return $ret;
            }
        }

        function frontend_enqueue($layout_type, $unload_modernizr){

            wp_enqueue_style( 'dashicons' );
            wp_enqueue_style('fat-maika', FAT_MAIKA_PLUGIN_URL . '/assets/css/frontend/fat-maika.css', array(), '1.15');
            wp_enqueue_style('fat-maika-simple-icon', FAT_MAIKA_PLUGIN_URL. '/assets/fonts/simple-icon/css/simple-line-icons.css', array(), '1.0.0');
            wp_enqueue_style('jquery-light-gallery', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/light-gallery/css/lightgallery.min.css', array(), false);
            wp_enqueue_style('jquery-light-gallery-transition', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/light-gallery/css/lg-transitions.min.css', array(), false);
            wp_enqueue_style('jquery-magnific-popup', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/magnific-popup/magnific-popup.css', array(), '1.1.0');

            //some theme missing select2
            wp_enqueue_script('select2', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.5/js/select2.min.js', array('jquery'), false, true);
            wp_enqueue_script('jquery-light-gallery', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/light-gallery/js/lightgallery.min.js', array('jquery'), false, true);
            wp_enqueue_script('jquery-magnific-popup', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/magnific-popup/jquery.magnific-popup.min.js', array('jquery'), false, true);
            wp_enqueue_script('images-loaded', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/isotope/imagesloaded.pkgd.min.js', array('jquery'), false, true);

            switch ($layout_type){
                case 'before-after':{
                    wp_enqueue_style('image-comparison', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/image-comparison/jquery-image-comparison.min.css', array(), false);
                    wp_enqueue_script('image-comparison', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/image-comparison/jquery-image-comparison.js', array('jquery'), false, true);
                    break;
                }
                case 'horizontal-slide':{
                    wp_enqueue_style('horizontal-slide', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/horizontal-slide/horizontal-slide.css', array(), false);
                    wp_enqueue_style('perfect-scrollbar', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/perfect-scrollbar/css/perfect-scrollbar.min.css', array(), false);
                    if($unload_modernizr!='1'){
                        wp_enqueue_script('modernizr-1.5', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/horizontal-slide/modernizr-1.5.min.js', array('jquery'), false, true);
                    }
                    wp_enqueue_script('jquery.mousewheel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/horizontal-slide/jquery.mousewheel.js', array('jquery'), false, true);
                    wp_enqueue_script('perfect-scrollbar', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/perfect-scrollbar/js/perfect-scrollbar.jquery.min.js', array('jquery'), false, true);
                    wp_enqueue_script('horizontal-slide', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/horizontal-slide/horizontal-slide.js', array('jquery','jquery.mousewheel'), false, true);
                    break;
                }
                case 'carousel-slide':{
                    wp_enqueue_style('owl-carousel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/owl-carousel/assets/owl.carousel.min.css', array(), '2.3.4');
                    if($unload_modernizr!='1'){
                        wp_enqueue_script('modernizr-1.5', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/horizontal-slide/modernizr-1.5.min.js', array('jquery'), false, true);
                    }
                    wp_enqueue_script('owl-carousel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/owl-carousel/owl.carousel.min.js', array('jquery'), '2.3.4', true);
                    break;
                }
                case 'photopile':{
                    wp_enqueue_style('photopile', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/photopile/css/photopile.css', array(), false);
                    wp_enqueue_script('photopile_touch', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/photopile/js/jquery.touch.punch.js', array('jquery'), false, true);
                    wp_register_script('photopile', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/photopile/js/photopile.js', array('jquery','jquery-ui-core', 'jquery-ui-draggable', 'jquery-ui-droppable','jquery-ui-sortable','underscore','backbone'), false, true);
                    wp_localize_script('photopile', 'photopile_resource', array('img' => FAT_MAIKA_PLUGIN_URL.'/assets/plugins/photopile/images'));
                    wp_enqueue_script('photopile');
                    break;
                }
                case 'timeline':{
                    wp_enqueue_style('timeline', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/timeline/css/style.css', array(), false);
                    if($unload_modernizr!='1'){
                        wp_enqueue_script('modernizr', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/timeline/js/modernizr.js', array('jquery'), false, true);
                    }
                    wp_enqueue_script('timeline', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/timeline/js/main.js', array('jquery'), false, true);
                    break;
                }
                case 'album-preview':{
                    wp_enqueue_style('album-preview', FAT_MAIKA_PLUGIN_URL. '/assets/plugins/album-preview/css/album-animation.css', array(), false);
                    break;
                }
                case 'justified':{
                    wp_enqueue_style('justified', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/justifiedGallery/justifiedGallery.min.css', array(), false);
                    wp_enqueue_script('justified', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/justifiedGallery/jquery.justifiedGallery.min.js', array('jquery'), false, true);
                    break;
                }
                default:{
                    wp_enqueue_style('fat-animate', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/animate/animate.css', array(), false);
                    wp_enqueue_style('carousel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/owl-carousel/assets/owl.carousel.min.css', array(), false);

                    wp_enqueue_script('carousel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/owl-carousel/owl.carousel.min.js', array('jquery'), false, true);
                    wp_enqueue_script('fat-isotope', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/isotope/isotope.pkgd.min.js', array('jquery'), '3.0.5', true);
                    wp_enqueue_script('fat-masonry', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/isotope/masonry.pkgd.min.js', array('jquery'), false, true);
                    if($unload_modernizr!='1'){
                        wp_enqueue_script('modernizr', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/modernizr-custom.js', array('jquery'), false, true);
                    }

                }
            }
            $ver = uniqid();
            wp_enqueue_script('fat-maika',  FAT_MAIKA_PLUGIN_URL . '/assets/js/fat-maika.js?v='.$ver,array('jquery'), '1.21', true );
        }

        function frontend_enqueue_ajax(){
            wp_enqueue_style( 'dashicons' );
            wp_enqueue_style('fat-maika', FAT_MAIKA_PLUGIN_URL . '/assets/css/frontend/fat-maika.css', array(), '1.4.9');
            wp_enqueue_style('fat-maika-simple-icon', FAT_MAIKA_PLUGIN_URL. '/assets/fonts/simple-icon/css/simple-line-icons.css', array(), '1.0.0');
            wp_enqueue_style('jquery-light-gallery', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/light-gallery/css/lightgallery.min.css', array(), false);
            wp_enqueue_style('jquery-light-gallery-transition', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/light-gallery/css/lg-transitions.min.css', array(), false);
            wp_enqueue_style('jquery-magnific-popup', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/magnific-popup/magnific-popup.css', array(), '1.1.0');

            //some theme missing select2
            wp_enqueue_script('select2', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.5/js/select2.min.js', array('jquery'), false, true);
            wp_enqueue_script('jquery-light-gallery', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/light-gallery/js/lightgallery.min.js', array('jquery'), false, true);
            wp_enqueue_script('jquery-magnific-popup', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/magnific-popup/jquery.magnific-popup.min.js', array('jquery'), false, true);
            wp_enqueue_script('images-loaded', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/isotope/imagesloaded.pkgd.min.js', array('jquery'), false, true);

            wp_enqueue_style('justified', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/justifiedGallery/justifiedGallery.min.css', array(), false);
            wp_enqueue_script('justified', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/justifiedGallery/jquery.justifiedGallery.min.js', array('jquery'), false, true);
            wp_enqueue_style('album-preview', FAT_MAIKA_PLUGIN_URL. '/assets/plugins/album-preview/css/album-animation.css', array(), false);
            wp_enqueue_style('horizontal-slide', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/horizontal-slide/horizontal-slide.css', array(), false);
            wp_enqueue_style('perfect-scrollbar', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/perfect-scrollbar/css/perfect-scrollbar.min.css', array(), false);
            wp_enqueue_script('jquery.mousewheel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/horizontal-slide/jquery.mousewheel.js', array('jquery'), false, true);
            wp_enqueue_script('perfect-scrollbar', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/perfect-scrollbar/js/perfect-scrollbar.jquery.min.js', array('jquery'), false, true);
            wp_enqueue_script('horizontal-slide', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/horizontal-slide/horizontal-slide.js', array('jquery','jquery.mousewheel'), false, true);
            wp_enqueue_style('image-comparison', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/image-comparison/jquery-image-comparison.min.css', array(), false);
            wp_enqueue_script('image-comparison', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/image-comparison/jquery-image-comparison.js', array('jquery'), false, true);

            wp_enqueue_style('fat-animate', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/animate/animate.css', array(), false);
            wp_enqueue_style('carousel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/owl-carousel/assets/owl.carousel.min.css', array(), false);

            wp_enqueue_style('owl-carousel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/owl-carousel/assets/owl.carousel.min.css', array(), '2.3.4');
            wp_enqueue_script('owl-carousel', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/owl-carousel/owl.carousel.min.js', array('jquery'), '2.3.4', true);

            wp_enqueue_script('fat-isotope', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/isotope/isotope.pkgd.min.js', array('jquery'), '3.0.5', true);
            wp_enqueue_script('fat-masonry', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/isotope/masonry.pkgd.min.js', array('jquery'), false, true);
            wp_enqueue_script('modernizr', FAT_MAIKA_PLUGIN_URL . '/assets/plugins/modernizr-custom.js', array('jquery'), false, true);

            $ver = uniqid();
            wp_enqueue_script('fat-maika',  FAT_MAIKA_PLUGIN_URL . '/assets/js/fat-maika.js',array('jquery'), $ver, true );
        }

        function enqueue_script()
        {
            $wp_version = get_bloginfo('version');
            if ($wp_version == '5.9') {
                wp_enqueue_script( 'fix-jquery-ui', 'https://code.jquery.com/ui/1.13.1/jquery-ui.js', array('jquery-ui-sortable') );
            }
            wp_enqueue_style('fat-custom-page-cmb-style', plugins_url('/assets/css/fat-page-cmb.css', __FILE__), array(), true);
            wp_enqueue_script('fat-page-cmb-js',  FAT_MAIKA_PLUGIN_URL . '/assets/js/fat-page-cmb.js',array('jquery'), false, true );
        }

        function includes(){
            include plugin_dir_path(__FILE__).'utils/utils.php';
            include plugin_dir_path(__FILE__).'utils/resize.php';
            //include plugin_dir_path(__FILE__).'install-demo/class-install-demo.php';
        }

        function includes_meta(){
            $theme_meta_path = get_template_directory() . '/libs/fat-cmb/fat-cmb.php';
            if(!file_exists($theme_meta_path)){
                include plugin_dir_path(__FILE__).'libs/fat-cmb/fat-cmb.php';
            }
        }

        function register_page_builder_shortcode()
        {
            $args = array(
                'posts_per_page' => -1,
                'post_type'      => FAT_MAIKA_GALLERY_POST_TYPE,
                'post_status'    => 'publish');
            $list_gallery = array();
            $post_array = get_posts($args);
            foreach ($post_array as $post) : setup_postdata($post);
                $list_gallery[$post->post_title] = $post->ID;
            endforeach;
            wp_reset_postdata();

            if (function_exists('vc_map')) {
                vc_map(array(
                    'name'        => 'FAT Maika Gallery',
                    'base'        => 'fat_maika',
                    'icon'        => 'dashicons dashicons-format-gallery',
                    'category'    => esc_html__('FAT Shortcode', 'maika'),
                    'description' => esc_html__('A custom gallery for your site', 'maika'),
                    'params'      => array(
                        array(
                            'type'        => 'dropdown',
                            'heading'     => esc_html__('Choose gallery', 'maika'),
                            'param_name'  => 'id',
                            'admin_label' => true,
                            'value'       => $list_gallery
                        ),
                    )
                ));
            }
        }

        public function add_admin_listing_shortcode_columns($columns)
        {
            unset(
                $columns['date']
            );
            $columns = array_merge($columns, array('shortcode' => esc_html__('Shortcodes', 'maika')));
            $columns = array_merge($columns, array('date' => esc_html__('Date', 'maika')));
            return $columns;
        }

        public function set_admin_listing_shortcode_columns_value($column, $post_id)
        {
            if ($column == 'shortcode') {
                echo '[fat_maika  id="' . $post_id . '"]';
            }
        }
    }

    new FAT_Maika();
}